summaryrefslogtreecommitdiffstats
path: root/src/demos/util
diff options
context:
space:
mode:
Diffstat (limited to 'src/demos/util')
-rw-r--r--src/demos/util/SGIImage.java4
-rw-r--r--src/demos/util/TGAImage.java6
2 files changed, 5 insertions, 5 deletions
diff --git a/src/demos/util/SGIImage.java b/src/demos/util/SGIImage.java
index df36e70..7d4468e 100644
--- a/src/demos/util/SGIImage.java
+++ b/src/demos/util/SGIImage.java
@@ -132,7 +132,7 @@ public class SGIImage {
return header.ysize;
}
/** Returns the OpenGL format for this texture; e.g. GL.GL_BGR_EXT or GL.GL_BGRA_EXT. */
public int getFormat() {
return format;
}
@@ -202,7 +202,7 @@ public class SGIImage {
rowSize = null;
tmpData = null;
tmpRead = null;
- format = GL.GL_BGRA_EXT;
+ format = GL.GL_BGRA;
}
private void getRow(byte[] buf, int y, int z) {
@@ -132,7 +132,7 @@ public class SGIImage {
return header.ysize;
}
- /** Returns the OpenGL format for this texture; e.g. GL.GL_BGR_EXT or GL.GL_BGRA_EXT. */
+ /** Returns the OpenGL format for this texture; e.g. GL.GL_BGR or GL.GL_BGRA. */
public int getFormat() {
return format;
diff --git a/src/demos/util/TGAImage.java b/src/demos/util/TGAImage.java
index c999c99..a99f4f3 100644
--- a/src/demos/util/TGAImage.java
+++ b/src/demos/util/TGAImage.java
@@ -272,10 +272,10 @@ public class TGAImage {
data = new byte[rawWidth * header.height()];
if (header.pixelDepth() == 24) {
- format = GL.GL_BGR_EXT;
+ format = GL.GL_BGR;
} else {
assert header.pixelDepth() == 32;
- format = GL.GL_BGRA_EXT;
+ format = GL.GL_BGRA;
}
for (i = 0; i < header.height(); ++i) {
@@ -296,7 +296,7 @@ public class TGAImage {
/** Returns the height of the image. */
public int getHeight() { return header.height(); }
/** Returns the OpenGL format for this texture; e.g. GL.GL_BGR_EXT or GL.GL_BGRA_EXT. */
public int getGLFormat() { return format; }
/** Returns the raw data for this texture in the correct
@@ -296,7 +296,7 @@ public class TGAImage {
/** Returns the height of the image. */
public int getHeight() { return header.height(); }
- /** Returns the OpenGL format for this texture; e.g. GL.GL_BGR_EXT or GL.GL_BGRA_EXT. */
+ /** Returns the OpenGL format for this texture; e.g. GL.GL_BGR or GL.GL_BGRA. */
public int getGLFormat() { return format; }
/** Returns the raw data for this texture in the correct